@@ -2,7 +2,7 @@ use serde_derive::Deserialize;
 
 use crate::error;
 
-#[derive(Deserialize)]
+#[derive(Debug, Clone, Deserialize)]
 pub struct Response {
     error: String,
     data: serde_json::Value,
